==> core_models-0.1.0.gem: app/controllers/core_models/people_and_companies/bank_payment_card_vendors_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class PeopleAndCompanies::BankPaymentCardVendorsController < CoreModelsController
    # GET /people_and_companies/bank_payment_card_vendors
    # GET /people_and_companies/bank_payment_card_vendors.json
    def index
      @people_and_companies_bank_payment_card_vendors = PeopleAndCompanies::BankPaymentCardVendor.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @people_and_companies_bank_payment_card_vendors }
      end
    end

    # GET /people_and_companies/bank_payment_card_vendors/1
    # GET /people_and_companies/bank_payment_card_vendors/1.json
    def show
      @people_and_companies_bank_payment_card_vendor = PeopleAndCompanies::BankPaymentCardVendor.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @people_and_companies_bank_payment_card_vendor }
      end
    end

    # GET /people_and_companies/bank_payment_card_vendors/new
    # GET /people_and_companies/bank_payment_card_vendors/new.json
    def new
      @people_and_companies_bank_payment_card_vendor = PeopleAndCompanies::BankPaymentCardVendor.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @people_and_companies_bank_payment_card_vendor }
      end
    end

    # GET /people_and_companies/bank_payment_card_vendors/1/edit
    def edit
      @people_and_companies_bank_payment_card_vendor = PeopleAndCompanies::BankPaymentCardVendor.find(params[:id])
    end

    # POST /people_and_companies/bank_payment_card_vendors
    # POST /people_and_companies/bank_payment_card_vendors.json
    def create
      @people_and_companies_bank_payment_card_vendor = PeopleAndCompanies::BankPaymentCardVendor.new(params[:people_and_companies_bank_payment_card_vendor])

      respond_to do |format|
        if @people_and_companies_bank_payment_card_vendor.save
          format.html { redirect_to @people_and_companies_bank_payment_card_vendor, :notice => 'Bank payment card vendor was successfully created.' }
          format.json { render :json => @people_and_companies_bank_payment_card_vendor, :status => :created, :location => @people_and_companies_bank_payment_card_vendor }
        else
          format.html { render :action => "new" }
          format.json { render :json => @people_and_companies_bank_payment_card_vendor.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /people_and_companies/bank_payment_card_vendors/1
    # PUT /people_and_companies/bank_payment_card_vendors/1.json
    def update
      @people_and_companies_bank_payment_card_vendor = PeopleAndCompanies::BankPaymentCardVendor.find(params[:id])

      respond_to do |format|
        if @people_and_companies_bank_payment_card_vendor.update_attributes(params[:people_and_companies_bank_payment_card_vendor])
          format.html { redirect_to @people_and_companies_bank_payment_card_vendor, :notice => 'Bank payment card vendor was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @people_and_companies_bank_payment_card_vendor.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /people_and_companies/bank_payment_card_vendors/1
    # DELETE /people_and_companies/bank_payment_card_vendors/1.json
    def destroy
      @people_and_companies_bank_payment_card_vendor = PeopleAndCompanies::BankPaymentCardVendor.find(params[:id])
      @people_and_companies_bank_payment_card_vendor.destroy

      respond_to do |format|
        format.html { redirect_to people_and_companies_bank_payment_card_vendors_url }
        format.json { head :no_content }
      end
    end
  end
end

==> core_models-0.2.9.gem: app/controllers/core_models/people_and_companies/bank_payment_card_vendors_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class PeopleAndCompanies::BankPaymentCardVendorsController < CoreModelsController
    # GET /people_and_companies/bank_payment_card_vendors
    # GET /people_and_companies/bank_payment_card_vendors.json
    def index
      @people_and_companies_bank_payment_card_vendors = PeopleAndCompanies::BankPaymentCardVendor.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @people_and_companies_bank_payment_card_vendors }
      end
    end

    # GET /people_and_companies/bank_payment_card_vendors/1
    # GET /people_and_companies/bank_payment_card_vendors/1.json
    def show
      @people_and_companies_bank_payment_card_vendor = PeopleAndCompanies::BankPaymentCardVendor.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @people_and_companies_bank_payment_card_vendor }
      end
    end

    # GET /people_and_companies/bank_payment_card_vendors/new
    # GET /people_and_companies/bank_payment_card_vendors/new.json
    def new
      @people_and_companies_bank_payment_card_vendor = PeopleAndCompanies::BankPaymentCardVendor.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @people_and_companies_bank_payment_card_vendor }
      end
    end

    # GET /people_and_companies/bank_payment_card_vendors/1/edit
    def edit
      @people_and_companies_bank_payment_card_vendor = PeopleAndCompanies::BankPaymentCardVendor.find(params[:id])
    end

    # POST /people_and_companies/bank_payment_card_vendors
    # POST /people_and_companies/bank_payment_card_vendors.json
    def create
      @people_and_companies_bank_payment_card_vendor = PeopleAndCompanies::BankPaymentCardVendor.new(params[:people_and_companies_bank_payment_card_vendor])

      respond_to do |format|
        if @people_and_companies_bank_payment_card_vendor.save
          format.html { redirect_to @people_and_companies_bank_payment_card_vendor, :notice => 'Bank payment card vendor was successfully created.' }
          format.json { render :json => @people_and_companies_bank_payment_card_vendor, :status => :created, :location => @people_and_companies_bank_payment_card_vendor }
        else
          format.html { render :action => "new" }
          format.json { render :json => @people_and_companies_bank_payment_card_vendor.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /people_and_companies/bank_payment_card_vendors/1
    # PUT /people_and_companies/bank_payment_card_vendors/1.json
    def update
      @people_and_companies_bank_payment_card_vendor = PeopleAndCompanies::BankPaymentCardVendor.find(params[:id])

      respond_to do |format|
        if @people_and_companies_bank_payment_card_vendor.update(params[:people_and_companies_bank_payment_card_vendor])
          format.html { redirect_to @people_and_companies_bank_payment_card_vendor, :notice => 'Bank payment card vendor was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @people_and_companies_bank_payment_card_vendor.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /people_and_companies/bank_payment_card_vendors/1
    # DELETE /people_and_companies/bank_payment_card_vendors/1.json
    def destroy
      @people_and_companies_bank_payment_card_vendor = PeopleAndCompanies::BankPaymentCardVendor.find(params[:id])
      @people_and_companies_bank_payment_card_vendor.destroy

      respond_to do |format|
        format.html { redirect_to people_and_companies_bank_payment_card_vendors_url }
        format.json { head :no_content }
      end
    end
  end
end
